#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-AfKVKyMx4HH1eszOlgqdwR
key:                  http-streams-0.8.9.9-AfKVKyMx4HH1eszOlgqdwR
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  ff56b62c75c7aabd3e9ff6a8106bd73a
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-AfKVKyMx4HH1eszOlgqdwR
depends:
    HsOpenSSL-0.11.7.9-DsLp9TSiswu8wFdWF66lvD
    aeson-2.2.1.0-28ssJzlQESE12G8XLETNIx
    attoparsec-0.14.4-AfQXKZj0AFm4MwPZbnzhvC
    attoparsec-aeson-2.2.0.0-DlKXxi8T2Ie5eXoPFSduUC base-4.18.2.1
    base64-bytestring-1.2.1.0-746voJok0ldKgJVOvUeNqZ
    blaze-builder-0.4.4.1-Al5BhVKOFsKDBdNQOvb6XG bytestring-0.11.5.3
    case-insensitive-1.2.1.0-77TInwzUoLr4ZTB9XsbUbo directory-1.3.8.5
    filepath-1.4.300.1 http-common-0.8.3.4-CtzhGAp78Z04Jq081mD0kL
    io-streams-1.5.2.2-7qh7UHxV5e2AP9OxYgEB7n mtl-2.3.1
    network-3.1.4.0-9YNBV8UGnKyEcMIeWoZU
    network-uri-2.6.4.2-Gnw0MjQFVGhFnasOtB45
    openssl-streams-1.2.3.0-IFxSeYCwQvq6M7uyOzH2CF text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-ZzaTCzIdz8BWoPLHKXAc8

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

